@@ -3,6 +3,7 @@
 #include <termios.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <ncurses.h>
 #include "eisl.h"
 #include "fmt.h"
 #include "except.h"
@@ -127,8 +128,8 @@ void display_buffer()
 		while (buffer[col][0] != NUL && buffer[col][0] != EOL) {
 		    putchar(buffer[col][0]);
 		    col++;
-		    if (buffer[col - 1][0] == '"' &&
-			buffer[col - 2][0] != '\\')
+		    if (buffer[col - 1][0] == '"'
+			&& buffer[col - 2][0] != '\\')
 			break;
 		}
 		ESCRST();
@@ -891,7 +892,6 @@ read_line_loop(int c, int *j, int *uni_j, int *pos, int limit,
 	    return false;
 	case 'q':		// Esc+q
 	    putchar('\n');
-	    greeting_flag = false;
 	    RAISE(Exit_Interp);
 	    break;
 	case ARROW_PREFIX:
